@@ -729,8 +729,10 @@ initlisp(void) {
 	NewInit();
 
         if ( NULL_OR_ON_C_STACK(&j) == 0
+#if defined(IM_FIX_BASE)
              || NULL_OR_ON_C_STACK(IM_FIX_BASE) == 0
              || NULL_OR_ON_C_STACK((IM_FIX_BASE|IM_FIX_LIM)) == 0
+#endif
              || NULL_OR_ON_C_STACK(Cnil) != 0
              || (((unsigned long )core_end) !=0
                   && NULL_OR_ON_C_STACK(core_end) != 0))
@@ -1240,6 +1242,10 @@ init_main(void) {
   ADD_FEATURE("SWITCH");
 #endif
 
+#ifndef NODYNEXT
+  ADD_FEATURE("DYNAMIC-EXTENT");
+#endif
+
 #ifndef NOINTDIV
   ADD_FEATURE("INTDIV");
 #endif
